@@ -1,6 +1,8 @@
 from zope.component.interfaces import IFactory
 from zope.interface import Attribute
 from zope.interface import Interface
+from zope.interface.interfaces import IObjectEvent
+from repoze.folder.interfaces import IFolder
 
 
 class IContentFactory(IFactory):
@@ -17,22 +19,33 @@ class IFieldFactory(IFactory):
     """ Factory for fields. Works the same way as IFactory. """
 
 
-class IObjectUpdatedEvent(Interface):
+class IObjectUpdatedEvent(IObjectEvent):
     """ Event sent when fields have been updated. """
     object = Attribute("The object this event is for.")
     fields = Attribute("Fields that have been updated."
                        "Should be a list with regular strings that correspond to field keys.")
     
     def __init__(object, fields=(),):
-        """ Init event. Usuallu done like this: 
+        """ Init event. Usually done like this:
             >>> from zope.component.event import objectEventNotify
             >>> context = SomeClass()
             >>> event = ObjectUpdatedEvent(context, fields=('updated', 'fields')
             >>> objectEventNotify(event)
         """
-    
 
-class IBaseFolder(Interface):
+
+class ISchemaCreatedEvent(IObjectEvent):
+    """ Fires when a schema object has been created."""
+    object = Attribute("The object this event is for - always an instantiated schema")
+
+
+class ISchemaBoundEvent(IObjectEvent):
+    """ """
+    object = Attribute("The object this event is for - always an instantiated schema")
+    kw = Attribute("A dict of the key/values that was used in schema.bind()")
+
+
+class IBaseFolder(IFolder):
     """ Base content type for all regular persistent models."""
     title = Attribute("Title")
     created = Attribute(
@@ -44,21 +57,31 @@ class IBaseFolder(Interface):
     schemas = Attribute(
         """ Dict that contains a mapping for action -> schema factory name.
             Example:{'edit':'site_root_edit_schema'}.""")
+
     allowed_contexts = Attribute(
         " List of which contexts this content is allowed in. Should correspond to content_type")
+
     content_type = Attribute("The id of this content type.")
+
     custom_accessors = Attribute(
         """ Dict of custom accessors to use. The key is which field to override,
             value should be a string which represent a callable on this class, or a callable method.
             The accessor method must accept default and key as kwarg.""")
+
     custom_mutators = Attribute(
         """ Same as custon accessor, but the callable must accept a value.
             The mutator method must accept value as argument.
             Method must also accept key as kwarg.""")
+
     custom_fields = Attribute(
         """ A dict of fields consisting of key (field name) and field factory name.
             A field type must be registered with that factory name.
-            Example: {'wiki_text':'VersioningField'} if your register a field factory with the name 'VersioningField'.""")
+            Example: {'wiki_text':'VersioningField'} if your register a field factory
+            with the name 'VersioningField'.""")
+
+    field_storage = Attribute(
+        """ An OOBTree storage for field values. The point of exposing this
+            is to enable bypass of custom mutators or accessors.""")
 
     def __init__(data=None, **kwargs):
         """ Init class. Any kwargs passed will be stored in this content. """
@@ -82,12 +105,11 @@ class IBaseFolder(Interface):
             - Retrieve data from normal storage and return.
         """
     
-    def set_field_value(key, value, override=False):
+    def set_field_value(key, value):
         """ Set field value.
             Will not send events, so use this if you silently want to change a single field.
             You can override field behaviour by either setting custom mutators
             or make a field a custom field.
-            override bypasses any custom mutators. Good idea if you're calling from a custom mutator.
         """
 
     def get_field_appstruct(schema):
