@@ -5,8 +5,10 @@ import colander
 from pyramid import testing
 from zope.interface.verify import verifyObject
 from zope.interface.verify import verifyClass
-from zope.component.factory import Factory
 from zope.component.interfaces import ComponentLookupError
+from BTrees.OOBTree import OOBTree
+
+from betahaus.pyracont.exceptions import CustomFunctionLoopError
 
 
 class MockSchema(colander.Schema):
@@ -17,7 +19,8 @@ class MockSchema(colander.Schema):
 
 class BaseFolderTests(TestCase):
     def setUp(self):
-        self.config = testing.setUp()
+        request = testing.DummyRequest()
+        self.config = testing.setUp(request = request)
 
     def tearDown(self):
         testing.tearDown()
@@ -207,8 +210,34 @@ class BaseFolderTests(TestCase):
         def subscriber(obj, event):
             L.append(event)
         self.config.add_subscriber(subscriber, (IBaseFolder, IObjectUpdatedEvent,))
-        
         obj = self._cut()
         obj.set_field_appstruct({'a':1, 'b':2}, notify=True)
-        
         self.failUnless(IObjectUpdatedEvent.providedBy(L[0]))
+
+    def test_avoid_loops_on_custom_accessors(self):
+
+        class _DummyCls(self._cut):
+            """ This class will create a loop, since the custom accessor calls itself
+            """
+            custom_accessors = {'test':'get_test'}
+            def get_test(self, **kwargs):
+                return self.get_field_value('test')
+        
+        obj = _DummyCls()
+        self.assertRaises(CustomFunctionLoopError, obj.get_field_value, 'test')
+
+    def test_avoid_loops_on_custom_mutators(self):
+
+        class _DummyCls(self._cut):
+            """ This class will create a loop, since the custom mutator calls itself
+            """
+            custom_mutators = {'test':'set_test'}
+            def set_test(self, value, **kwargs):
+                return self.set_field_value('test', value)
+        
+        obj = _DummyCls()
+        self.assertRaises(CustomFunctionLoopError, obj.set_field_value, 'test', 'value')
+
+    def test_field_storage(self):
+        obj = self._cut()
+        self.assertTrue(isinstance(obj.field_storage, OOBTree))
